Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1092)

Unified Diff: chrome/browser/defaults.h

Issue 482006: Make a shared app menu model and update win and mac to use it. Remove the NSM... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/cocoa/toolbar_controller.mm ('k') | chrome/browser/defaults.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/defaults.h
===================================================================
--- chrome/browser/defaults.h (revision 34553)
+++ chrome/browser/defaults.h (working copy)
@@ -41,12 +41,15 @@
extern const bool kBrowserAliveWithNoWindows;
// Should a link be shown on the bookmark bar allowing the user to import
-// bookmarks.
+// bookmarks?
extern const bool kShowImportOnBookmarkBar;
// Should the exit menu be shown?
extern const bool kShowExitMenuItem;
+// Should the about menu item be shown in the toolbar app menu?
+extern const bool kShowAboutMenuItem;
+
// Does the OS support other browsers? If not, operations such as default
// browser check are not done.
extern const bool kOSSupportsOtherBrowsers;
@@ -41,12 +41,15 @@
extern const bool kShowImportOnBookmarkBar;
-// Should the exit menu be shown?
+// Should the exit menu item be shown in the toolbar menu?
extern const bool kShowExitMenuItem;
« no previous file with comments | « chrome/browser/cocoa/toolbar_controller.mm ('k') | chrome/browser/defaults.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698